@@ -2,12 +2,9 @@
 #' @description From a graph, obtain an edge data frame
 #' with all current edge attributes.
 #' @param graph a graph object of class
-#' \code{dgr_graph} that is created using
-#' \code{create_graph}.
+#' \code{dgr_graph}.
 #' @return an edge data frame.
 #' @examples
-#' library(magrittr)
-#'
 #' # Create a graph using several piped functions
 #' graph <-
 #'   create_graph() %>%
@@ -24,23 +21,24 @@
 #'     "color", "blue") %>%
 #'   set_edge_attrs_ws(
 #'     "rel", "b") %>%
-#'   clear_selection
+#'   clear_selection()
 #'
 #' # Get the graph's internal edge data frame (edf)
-#' graph %>% get_edge_df
-#' #>   from to rel color
-#' #> 1    1  2   b  blue
-#' #> 2    1  3   a green
-#' #> 3    1  4   a green
-#' #> 4    1  5   a green
-#' #> 5    1  6   b  blue
+#' graph %>% get_edge_df()
+#' #>   id from to rel color
+#' #> 1  1    1  2   b  blue
+#' #> 2  2    1  3   a green
+#' #> 3  3    1  4   a green
+#' #> 4  4    1  5   a green
+#' #> 5  5    1  6   b  blue
 #' @export get_edge_df
 
 get_edge_df <- function(graph) {
 
-  if (is.null(graph$edges_df)) {
-    return(NA)
-  } else {
-    return(graph$edges_df)
+  # Validation: Graph object is valid
+  if (graph_object_valid(graph) == FALSE) {
+    stop("The graph object is not valid.")
   }
+
+  return(graph$edges_df)
 }
