@@ -6,17 +6,21 @@
 #' @return the graph diameter as a single-length
 #' vector.
 #' @examples
-#' # Get the graph diameter for a randomly-created
-#' # graph
+#' # Get the graph diameter for a
+#' # randomly-created graph
 #' get_graph_diameter(
 #'   create_random_graph(
-#'     5, 7,
-#'     fully_connected = TRUE,
-#'     set_seed = 20))
-#' #> [1] 4
+#'     n = 5, m = 7,
+#'     set_seed = 23))
+#' #> [1] 3
 #' @export get_graph_diameter
 
 get_graph_diameter <- function(graph) {
 
+  # Validation: Graph object is valid
+  if (graph_object_valid(graph) == FALSE) {
+    stop("The graph object is not valid.")
+  }
+
   return(max(get_eccentricity(graph)))
 }
