@@ -2,12 +2,9 @@
 #' @description From a graph, obtain a node data frame
 #' with all current node attributes.
 #' @param graph a graph object of class
-#' \code{dgr_graph} that is created using
-#' \code{create_graph}.
+#' \code{dgr_graph}.
 #' @return a node data frame.
 #' @examples
-#' library(magrittr)
-#'
 #' # Create a graph using several piped functions
 #' graph <-
 #'   create_graph() %>%
@@ -17,32 +14,34 @@
 #'   select_nodes_by_id(1) %>%
 #'   set_node_attrs_ws(
 #'     "value", 25.3) %>%
-#'   clear_selection %>%
+#'   clear_selection() %>%
 #'   select_nodes_by_id(2:4) %>%
 #'   set_node_attrs_ws(
 #'     "color", "grey70") %>%
-#'   invert_selection %>%
+#'   invert_selection() %>%
 #'   set_node_attrs_ws(
 #'     "color", "grey80") %>%
-#'   clear_selection %>%
-#'   select_nodes("value", "<15") %>%
-#'   set_node_attrs_ws(
-#'     "value", 10.0) %>%
 #'   clear_selection
 #'
-#' # Get the graph's internal node data frame (ndf)
-#' graph %>% get_node_df
-#' #>   nodes type label value  color
-#' #> 1     1    a        25.3 grey80
-#' #> 2     2    b     2    10 grey70
-#' #> 3     3    b     3    10 grey70
-#' #> 4     4    b     4    10 grey70
-#' #> 5     5    b     5    10 grey80
-#' #> 6     6    b     6    10 grey80
+#' # Get the graph's internal node
+#' # data frame (ndf)
+#' graph %>% get_node_df()
+#' #>   id type label value  color
+#' #> 1  1    a  <NA>  25.3 grey80
+#' #> 2  2    b  <NA>    NA grey70
+#' #> 3  3    b  <NA>    NA grey70
+#' #> 4  4    b  <NA>    NA grey70
+#' #> 5  5    b  <NA>    NA grey80
+#' #> 6  6    b  <NA>    NA grey80
 #' @export get_node_df
 
 get_node_df <- function(graph) {
 
+  # Validation: Graph object is valid
+  if (graph_object_valid(graph) == FALSE) {
+    stop("The graph object is not valid.")
+  }
+
   if (is.null(graph$nodes_df)) {
     return(NA)
   } else {
