@@ -14,13 +14,14 @@
 #' @param distance a vector of integer values that
 #' specify which of the valid paths to return when
 #' filtering by distance.
+#' @return a list of paths, sorted by ascending
+#' traversal length, comprising vectors of node IDs in
+#' sequence of traversal through the graph.
 #' @examples
-#' library(magrittr)
-#'
 #' # Create a simple graph
 #' graph <-
 #'   create_graph() %>%
-#'   add_node_df(create_nodes(1:8)) %>%
+#'   add_n_nodes(8) %>%
 #'   add_edge(1, 2) %>%
 #'   add_edge(1, 3) %>%
 #'   add_edge(3, 4) %>%
@@ -31,70 +32,61 @@
 #'   add_edge(4, 8)
 #'
 #' # Get a list of all paths outward from node `1`
-#' get_paths(graph, from = "1")
+#' get_paths(graph, from = 1)
 #' #> [[1]]
-#' #> [1] "1" "3" "5"
+#' #> [1] 1 3 5
 #' #>
 #' #> [[2]]
-#' #> [1] "1" "2" "7" "5"
+#' #> [1] 1 2 7 5
 #' #>
 #' #> [[3]]
-#' #> [1] "1" "3" "4" "6"
+#' #> [1] 1 3 4 6
 #' #>
 #' #> [[4]]
-#' #> [1] "1" "3" "4" "8"
+#' #> [1] 1 3 4 8
 #'
 #' # Get a list of all paths leading to node `6`
-#' get_paths(graph, to = "6")
+#' get_paths(graph, to = 6)
 #' #> [[1]]
-#' #> [1] "4" "6"
-#' #>
-#' #> [[2]]
-#' #> [1] "3" "4" "6"
-#' #>
-#' #> [[3]]
-#' #> [1] "1" "3" "4" "6"
+#' #> [1] 1 3 4 6
 #'
 #' # Get a list of all paths from `1` to `5`
-#' get_paths(graph, from = "1", to = "5")
+#' get_paths(graph, from = 1, to = 5)
 #' #> [[1]]
-#' #> [1] "1" "3" "5"
+#' #> [1] 1 3 5
 #' #>
 #' #> [[2]]
-#' #> [1] "1" "2" "7" "5"
+#' #> [1] 1 2 7 5
 #'
 #' # Get a list of all paths from `1` up to a distance
 #' # of 2 node traversals
-#' get_paths(graph, from = "1", distance = 2)
+#' get_paths(graph, from = 1, distance = 2)
 #' #> [[1]]
-#' #> [1] "1" "3" "5"
+#' #> [1] 1 3 5
 #' #>
 #' #> [[2]]
-#' #> [1] "1" "2" "7"
+#' #> [1] 1 2 7
 #' #>
 #' #> [[3]]
-#' #> [1] "1" "3" "4"
+#' #> [1] 1 3 4
 #'
 #' # Get a list of the shortest paths from `1` to `5`
 #' get_paths(
 #'   graph,
-#'   from = "1",
-#'   to = "5",
+#'   from = 1,
+#'   to = 5,
 #'   shortest_path = TRUE)
 #' #> [[1]]
-#' #> [1] "1" "3" "5"
+#' #> [1] 1 3 5
 #'
 #' # Get a list of the longest paths from `1` to `5`
 #' get_paths(
 #'   graph,
-#'   from = "1",
-#'   to = "5",
+#'   from = 1,
+#'   to = 5,
 #'   longest_path = TRUE)
 #' #> [[1]]
-#' #> [1] "1" "2" "7" "5"
-#' @return a list of paths, sorted by ascending
-#' traversal length, comprising vectors of node IDs in
-#' sequence of traversal through the graph.
+#' #> [1] 1 2 7 5
 #' @export get_paths
 
 get_paths <- function(graph,
@@ -104,6 +96,11 @@ get_paths <- function(graph,
                       longest_path = FALSE,
                       distance = NULL) {
 
+  # Validation: Graph object is valid
+  if (graph_object_valid(graph) == FALSE) {
+    stop("The graph object is not valid.")
+  }
+
   reverse_paths <- FALSE
 
   if (is.null(from) & !is.null(to)) {
