@@ -1,42 +1,52 @@
 #' Get node IDs for successor nodes to the specified
 #' node
 #' @description Provides a vector of node IDs for all
-#' nodes that have a
-#' connection from the given node.
+#' nodes that have a connection from the given node.
 #' @param graph a graph object of class
 #' \code{dgr_graph}.
 #' @param node a node ID for the selected node.
 #' @return a vector of node ID values.
 #' @examples
+#' # Set a seed
+#' set.seed(24)
+#'
 #' # Create a node data frame (ndf)
-#' nodes <-
-#'   create_nodes(
-#'     nodes = LETTERS)
+#' ndf <- create_node_df(26)
 #'
 #' # Create an edge data frame (edf)
-#' edges <-
-#'   create_edges(
-#'     from = sample(LETTERS, replace = TRUE),
-#'     to = sample(LETTERS, replace = TRUE))
+#' edf <-
+#'   create_edge_df(
+#'     from = sample(1:26, replace = TRUE),
+#'     to = sample(1:26, replace = TRUE))
 #'
 #' # From the ndf and edf, create a graph object
 #' graph <-
 #'   create_graph(
-#'     nodes_df = nodes,
-#'     edges_df = edges)
+#'     nodes_df = ndf,
+#'     edges_df = edf)
 #'
-#' # Get sucessors for node `A` in the graph
-#' get_successors(graph, node = "A")
-#' #> [1] "Z" "Y"
+#' # Get sucessors for node `4` in the graph
+#' get_successors(graph, node = 4)
+#' #> [1] 2 9
 #'
 #' # If there are no successors, NA is returned
-#' get_successors(graph, node = "Z")
+#' get_successors(graph, node = 1)
 #' #> [1] NA
 #' @export get_successors
 
 get_successors <- function(graph,
                            node) {
 
+  # Validation: Graph object is valid
+  if (graph_object_valid(graph) == FALSE) {
+    stop("The graph object is not valid.")
+  }
+
+  # If the graph contains no edges, return NA
+  if (is.null(graph$edges_df)) {
+    return(NA)
+  }
+
   # Determine whether the graph has any nodes
   graph_is_not_empty <- !is_graph_empty(graph)
 
