@@ -6,8 +6,6 @@
 #' \code{dgr_graph}.
 #' @return a logical value.
 #' @examples
-#' library(magrittr)
-#'
 #' # Create an empty graph; by default, new graphs
 #' # made by `create_graph()` are directed`
 #' graph <-
@@ -20,13 +18,18 @@
 #' # Use the `set_graph_undirected()` function and
 #' # check again whether the graph is directed
 #' graph %>%
-#'   set_graph_undirected %>%
-#'   is_graph_directed
+#'   set_graph_undirected() %>%
+#'   is_graph_directed()
 #' #> [1] FALSE
 #' @export is_graph_directed
 
 is_graph_directed <- function(graph) {
 
+  # Validation: Graph object is valid
+  if (graph_object_valid(graph) == FALSE) {
+    stop("The graph object is not valid.")
+  }
+
   # Determine if graph is directed by getting the
   # value at `graph$directed`
   graph_is_directed <- graph$directed
