@@ -9,30 +9,22 @@
 #' @return a graph series object of type
 #' \code{dgr_graph_1D}.
 #' @examples
-#' library(magrittr)
-#'
 #' # Create three graphs
 #' graph_1 <-
-#'   create_graph(
-#'     graph_name = "keep") %>%
-#'   add_node("a") %>%
-#'   add_node("b") %>%
-#'   add_node("c") %>%
-#'   add_edge("a", "c") %>%
-#'   add_edge("a", "b") %>%
-#'   add_edge("b", "c")
+#'   create_graph() %>%
+#'   add_n_nodes(3) %>%
+#'   add_edges_w_string(
+#'     "1->3 1->2 2->3")
 #'
 #' graph_2 <-
 #'   graph_1 %>%
-#'   add_node("d") %>%
-#'   add_edge("d", "c") %>%
-#'   set_graph_name("remove")
+#'   add_node() %>%
+#'   add_edge(4, 3)
 #'
 #' graph_3 <-
 #'   graph_2 %>%
-#'   add_node("e") %>%
-#'   add_edge("e", "b") %>%
-#'   set_graph_name("keep")
+#'   add_node() %>%
+#'   add_edge(5, 2)
 #'
 #' # Create an empty graph series and add
 #' # the graphs
@@ -53,8 +45,8 @@
 #' # the graph with the name `remove` was removed
 #' series_info(series)
 #' #>   graph name date_time   tz nodes edges directed
-#' #> 1     1 keep      <NA> <NA>     3     3     TRUE
-#' #> 2     2 keep      <NA> <NA>     5     5     TRUE
+#' #> 1     1 <NA>      <NA> <NA>     3     3     TRUE
+#' #> 2     2 <NA>      <NA> <NA>     5     5     TRUE
 #' @export remove_from_series
 
 remove_from_series <- function(graph_series,
@@ -70,7 +62,7 @@ remove_from_series <- function(graph_series,
     return(graph_series)
   }
 
-  if (class(index) == "numeric" | class(index) == "integer") {
+  if (inherits(index, "numeric") | inherits(index, "integer")) {
     graph_series$graphs[[index]] <- NULL
     return(graph_series)
   }
