@@ -2,8 +2,7 @@
 #' @description Set the time and timezone for a graph
 #' object of class \code{dgr_graph}.
 #' @param graph a graph object of class
-#' \code{dgr_graph} that is created using
-#' \code{create_graph}.
+#' \code{dgr_graph}.
 #' @param time the date-time to set for the graph.
 #' @param tz the timezone to set for the graph.
 #' @examples
@@ -37,6 +36,14 @@ set_graph_time <- function(graph,
                            time = NULL,
                            tz = NULL) {
 
+  # Get the time of function start
+  time_function_start <- Sys.time()
+
+  # Validation: Graph object is valid
+  if (graph_object_valid(graph) == FALSE) {
+    stop("The graph object is not valid.")
+  }
+
   if (is.null(time) & is.null(tz)) {
     time <- format(Sys.time(), "%Y-%m-%d %H:%M:%S")
     tz <- Sys.timezone()
@@ -61,23 +68,25 @@ set_graph_time <- function(graph,
     tz <- "GMT"
   }
 
-  dgr_graph <-
-    create_graph(
-      nodes_df = graph$nodes_df,
-      edges_df = graph$nodes_df,
-      graph_attrs = graph$graph_attrs,
-      node_attrs = graph$node_attrs,
-      edge_attrs = graph$edge_attrs,
-      directed = ifelse(is_graph_directed(graph),
-                        TRUE, FALSE),
-      graph_name = graph$graph_name,
-      graph_time = ifelse(!is.null(time),
-                          time, graph$graph_time),
-      graph_tz = tz)
+  # Modify the graph's time and time zone attributes
+  graph$graph_info$graph_time[1] <- time
+  graph$graph_info$graph_tz[1] <- tz
 
-  if (!is.null(graph$selection)) {
-    dgr_graph$selection <- graph$selection
+  # Update the `graph_log` df with an action
+  graph$graph_log <-
+    add_action_to_log(
+      graph_log = graph$graph_log,
+      version_id = nrow(graph$graph_log) + 1,
+      function_used = "set_graph_time",
+      time_modified = time_function_start,
+      duration = graph_function_duration(time_function_start),
+      nodes = nrow(graph$nodes_df),
+      edges = nrow(graph$edges_df))
+
+  # Write graph backup if the option is set
+  if (graph$graph_info$write_backups) {
+    save_graph_as_rds(graph = graph)
   }
 
-  return(dgr_graph)
+  return(graph)
 }
