@@ -5,10 +5,10 @@ test_that("simple traversals are possible", {
   # Create a graph
   graph <-
     create_graph() %>%
-    add_node %>%
-    add_node %>%
-    add_node %>%
-    add_node %>%
+    add_node() %>%
+    add_node() %>%
+    add_node() %>%
+    add_node() %>%
     add_edge(1, 2) %>%
     add_edge(2, 3) %>%
     add_edge(3, 4)
@@ -19,108 +19,109 @@ test_that("simple traversals are possible", {
   graph <-
     graph %>%
     select_nodes(nodes = 1) %>%
-    trav_out %>%
-    trav_out %>%
-    trav_out
+    trav_out() %>%
+    trav_out() %>%
+    trav_out()
 
   # Expect that node `4` is the current selection
-  expect_equal(get_selection(graph), "4")
+  expect_equal(get_selection(graph), 4)
 
   # Traverse back to node `1` from node `4`
   graph <-
     graph %>%
-    trav_in %>%
-    trav_in %>%
-    trav_in
+    trav_in() %>%
+    trav_in() %>%
+    trav_in()
 
   # Expect that node `1` is the current selection
-  expect_equal(get_selection(graph), "1")
+  expect_equal(get_selection(graph), 1)
 
   # Traverse from node `1` to `2`, then, traverse nodes
   # in both directions
   graph <-
-    graph %>% trav_out %>% trav_both
+    graph %>%
+    trav_out() %>%
+    trav_both()
 
   # Expect that nodes `1` and `3` are in the
   # current selection
-  expect_true(all(c("1", "3") %in% get_selection(graph)))
+  expect_true(all(c(1, 3) %in% get_selection(graph)))
 
   # Traverse by moving from nodes onto edges, then,
   # onto nodes; from `1` to `4`
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes(nodes = 1) %>%
-    trav_out_edge %>%
-    trav_in_node %>%
-    trav_out_edge %>%
-    trav_in_node %>%
-    trav_out_edge %>%
-    trav_in_node
+    trav_out_edge() %>%
+    trav_in_node() %>%
+    trav_out_edge() %>%
+    trav_in_node() %>%
+    trav_out_edge() %>%
+    trav_in_node()
 
   # Expect that node `4` is the current selection
-  expect_equal(get_selection(graph), "4")
+  expect_equal(get_selection(graph), 4)
 
   # Traverse back to node `1` from node `4`, using the
   # same types of traversals
   graph <-
     graph %>%
-    trav_in_edge %>%
-    trav_out_node %>%
-    trav_in_edge %>%
-    trav_out_node %>%
-    trav_in_edge %>%
-    trav_out_node
+    trav_in_edge() %>%
+    trav_out_node() %>%
+    trav_in_edge() %>%
+    trav_out_node() %>%
+    trav_in_edge() %>%
+    trav_out_node()
 
   # Expect that node `1` is the current selection
-  expect_equal(get_selection(graph), "1")
+  expect_equal(get_selection(graph), 1)
 
   # Modify the graph so that it contains a branch
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes(nodes = 3) %>%
     add_n_nodes_ws(1, "from") %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes(nodes = 2) %>%
     add_n_nodes_ws(2, "from") %>%
-    clear_selection
+    clear_selection()
 
   # Traverse nodes from `1` until traverse can no
   # longer occur
   graph <-
     graph %>%
     select_nodes(nodes = 1) %>%
-    trav_out
+    trav_out()
 
   # Expect that node `2` is the current selection
-  expect_equal(get_selection(graph), "2")
+  expect_equal(get_selection(graph), 2)
 
   # Continue traversal outward by node
   graph <- graph %>% trav_out
 
   # Expect that nodes `3`, `6`, and `7` are in the
   # current selection
-  expect_equal(get_selection(graph), c("3", "6", "7"))
+  expect_equal(get_selection(graph), c(3, 6, 7))
 
   # Continue traversal outward by node
   graph <- graph %>% trav_out
 
   # Expect that nodes `4` and `5` are in the
   # current selection
-  expect_equal(get_selection(graph), c("4", "5"))
+  expect_equal(get_selection(graph), c(4, 5))
 
   # Continue traversal outward, even though at end
   graph <- graph %>% trav_out
 
   # Expect that nodes `4` and `5` are still in the
   # current selection
-  expect_equal(get_selection(graph), c("4", "5"))
+  expect_equal(get_selection(graph), c(4, 5))
 
   # Expect an error if attempting to perform a node
   # traversal without any selection of nodes
-  graph <-
-    graph %>% clear_selection()
+  graph <- graph %>% clear_selection
 
   expect_error(graph %>% trav_in)
   expect_error(graph %>% trav_out)
@@ -168,10 +169,10 @@ test_that("selective traversals with `trav_out()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(1) %>%
-    trav_out(node_attr = "data_value", match = "==10")
+    trav_out("data_value == 10")
 
   # Expect that node `2` is the current selection
-  expect_equal(get_selection(graph), "2")
+  expect_equal(get_selection(graph), 2)
 
   # Starting at node `1`, traverse to node `2`, using a
   # different match expression (<)
@@ -179,10 +180,10 @@ test_that("selective traversals with `trav_out()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(1) %>%
-    trav_out(node_attr = "data_value", match = "<15")
+    trav_out("data_value < 15")
 
   # Expect that node `2` is the current selection
-  expect_equal(get_selection(graph), "2")
+  expect_equal(get_selection(graph), 2)
 
   # Starting at node `1`, traverse to node `2`, using a
   # different match expression (>)
@@ -190,10 +191,10 @@ test_that("selective traversals with `trav_out()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(1) %>%
-    trav_out(node_attr = "data_value", match = ">5")
+    trav_out("data_value > 5")
 
   # Expect that node `2` is the current selection
-  expect_equal(get_selection(graph), "2")
+  expect_equal(get_selection(graph), 2)
 
   # Starting at node `1`, traverse to node `2`, using a
   # different match expression (!=)
@@ -201,10 +202,10 @@ test_that("selective traversals with `trav_out()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(1) %>%
-    trav_out(node_attr = "data_value", match = "!=5")
+    trav_out("data_value != 5")
 
   # Expect that node `2` is the current selection
-  expect_equal(get_selection(graph), "2")
+  expect_equal(get_selection(graph), 2)
 
   # Starting at node `1`, attempt to traverse to node
   # `2` using a match expression that won't yield
@@ -213,11 +214,11 @@ test_that("selective traversals with `trav_out()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(1) %>%
-    trav_out(node_attr = "data_value", match = "!=10")
+    trav_out("data_value != 10")
 
   # Expect that node `1` is the current selection (since
   # no traversal had occurred)
-  expect_equal(get_selection(graph), "1")
+  expect_equal(get_selection(graph), 1)
 
   # Starting at node `3`, traverse to node `4` using a
   # match on a character field
@@ -225,10 +226,10 @@ test_that("selective traversals with `trav_out()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(3) %>%
-    trav_out(node_attr = "shape", match = "square")
+    trav_out("shape == 'square'")
 
   # Expect that node `4` is the current selection
-  expect_equal(get_selection(graph), "4")
+  expect_equal(get_selection(graph), 4)
 
   # Starting at node `3`, attempt to traverse to node `4`
   # using a match expression that won't yield a match
@@ -236,10 +237,10 @@ test_that("selective traversals with `trav_out()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(3) %>%
-    trav_out(node_attr = "shape", match = "triangle")
+    trav_out("shape == 'triangle'")
 
   # Expect that node `4` is the current selection
-  expect_equal(get_selection(graph), "3")
+  expect_equal(get_selection(graph), 3)
 })
 
 test_that("selective traversals with `trav_in()` are possible", {
@@ -256,103 +257,103 @@ test_that("selective traversals with `trav_in()` are possible", {
     add_edge(3, 4) %>%
     select_nodes %>%
     set_node_attrs_ws("type", "circle") %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(c(2, 3)) %>%
     set_node_attrs_ws("data_value", 10) %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(4) %>%
     set_node_attrs_ws("shape", "square") %>%
     set_node_attrs_ws("data_value", 5) %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(1) %>%
     set_node_attrs_ws("shape", "triangle") %>%
     set_node_attrs_ws("data_value", 5) %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_edges() %>%
     set_edge_attrs_ws("data_value", 5) %>%
     set_edge_attrs_ws("rel", "related_to") %>%
-    clear_selection
+    clear_selection()
 
   # Starting at node `4`, traverse to node `3` with a
   # match expression (==)
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(4) %>%
-    trav_in(node_attr = "data_value", match = "==10")
+    trav_in("data_value == 10")
 
-  # Expect that node `2` is the current selection
-  expect_equal(get_selection(graph), "3")
+  # Expect that node `3` is the current selection
+  expect_equal(get_selection(graph), 3)
 
   # Starting at node `4`, traverse to node `3`, using a
   # different match expression (<)
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(4) %>%
-    trav_in(node_attr = "data_value", match = "<15")
+    trav_in("data_value < 15")
 
   # Expect that node `3` is the current selection
-  expect_equal(get_selection(graph), "3")
+  expect_equal(get_selection(graph), 3)
 
   # Starting at node `4`, traverse to node `3`, using a
   # different match expression (>)
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(4) %>%
-    trav_in(node_attr = "data_value", match = ">5")
+    trav_in("data_value > 5")
 
   # Expect that node `3` is the current selection
-  expect_equal(get_selection(graph), "3")
+  expect_equal(get_selection(graph), 3)
 
   # Starting at node `4`, traverse to node `3`, using a
   # different match expression (!=)
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(4) %>%
-    trav_in(node_attr = "data_value", match = "!=5")
+    trav_in("data_value != 5")
 
   # Expect that node `3` is the current selection
-  expect_equal(get_selection(graph), "3")
+  expect_equal(get_selection(graph), 3)
 
   # Starting at node `4`, attempt to traverse to
   # node `3` using a match expression that won't
   # yield a match
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(4) %>%
-    trav_in(node_attr = "data_value", match = "!=10")
+    trav_in("data_value != 10")
 
   # Expect that node `4` is the current selection
   # (since no traversal had occurred)
-  expect_equal(get_selection(graph), "4")
+  expect_equal(get_selection(graph), 4)
 
   # Starting at node `2`, traverse to node `1` using
   # a match on a character field
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(2) %>%
-    trav_in(node_attr = "shape", match = "triangle")
+    trav_in("shape == 'triangle'")
 
   # Expect that node `1` is the current selection
-  expect_equal(get_selection(graph), "1")
+  expect_equal(get_selection(graph), 1)
 
   # Starting at node `2`, attempt to traverse to
   # node `1` using a match expression that won't
   # yield a match
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(2) %>%
-    trav_in(node_attr = "shape", match = "square")
+    trav_in("shape == 'square'")
 
   # Expect that node `2` is the current selection
   # (since no traversal had occurred)
-  expect_equal(get_selection(graph), "2")
+  expect_equal(get_selection(graph), 2)
 })
 
 test_that("selective traversals with `trav_out_edge()` are possible", {
@@ -360,31 +361,31 @@ test_that("selective traversals with `trav_out_edge()` are possible", {
   # Create a graph
   graph <-
     create_graph() %>%
-    add_node %>%
-    add_node %>%
-    add_node %>%
-    add_node %>%
+    add_node() %>%
+    add_node() %>%
+    add_node() %>%
+    add_node() %>%
     add_edge(1, 2) %>%
     add_edge(2, 3) %>%
     add_edge(3, 4) %>%
-    select_nodes %>%
+    select_nodes() %>%
     set_node_attrs_ws("type", "circle") %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(c(2, 3)) %>%
     set_node_attrs_ws("data_value", 10) %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(4) %>%
     set_node_attrs_ws("shape", "square") %>%
     set_node_attrs_ws("data_value", 5) %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(1) %>%
     set_node_attrs_ws("shape", "triangle") %>%
     set_node_attrs_ws("data_value", 5) %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_edges() %>%
     set_edge_attrs_ws("data_value", 5) %>%
     set_edge_attrs_ws("rel", "related_to") %>%
-    clear_selection
+    clear_selection()
 
   # Starting at node `1`, traverse to edge between
   # nodes `1` and `2` with a match expression (==)
@@ -392,11 +393,11 @@ test_that("selective traversals with `trav_out_edge()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(1) %>%
-    trav_out_edge(edge_attr = "data_value", match = "==5")
+    trav_out_edge("data_value == 5")
 
   # Expect that the edge `1` -> `2` is the
   # current selection
-  expect_equal(get_selection(graph), "1 -> 2")
+  expect_equal(get_selection(graph), 1)
 
   # Starting at node `1`, traverse to edge between
   # nodes `1` and `2` with a match expression (<)
@@ -404,11 +405,11 @@ test_that("selective traversals with `trav_out_edge()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(1) %>%
-    trav_out_edge(edge_attr = "data_value", match = "<10")
+    trav_out_edge("data_value < 10")
 
   # Expect that the edge `1` -> `2` is the
   # current selection
-  expect_equal(get_selection(graph), "1 -> 2")
+  expect_equal(get_selection(graph), 1)
 
   # Starting at node `1`, traverse to edge between
   # nodes `1` and `2` with a match expression (>)
@@ -416,11 +417,11 @@ test_that("selective traversals with `trav_out_edge()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(1) %>%
-    trav_out_edge(edge_attr = "data_value", match = ">2")
+    trav_out_edge("data_value > 2")
 
   # Expect that the edge `1` -> `2` is the
   # current selection
-  expect_equal(get_selection(graph), "1 -> 2")
+  expect_equal(get_selection(graph), 1)
 
   # Starting at node `1`, traverse to edge between
   # nodes `1` and `2` with a match expression (!=)
@@ -428,11 +429,11 @@ test_that("selective traversals with `trav_out_edge()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(1) %>%
-    trav_out_edge(edge_attr = "data_value", match = "!=1")
+    trav_out_edge("data_value != 1")
 
   # Expect that the edge `1` -> `2` is the
   # current selection
-  expect_equal(get_selection(graph), "1 -> 2")
+  expect_equal(get_selection(graph), 1)
 
   # Starting at node `1`, attempt to traverse to edge
   # between nodes `1` and `2` using a match expression
@@ -441,11 +442,11 @@ test_that("selective traversals with `trav_out_edge()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(1) %>%
-    trav_out_edge(edge_attr = "data_value", match = "!=5")
+    trav_out_edge("data_value != 5")
 
   # Expect that node `1` is the current selection
   # (since no traversal had occurred)
-  expect_equal(get_selection(graph), "1")
+  expect_equal(get_selection(graph), 1)
 
   # Starting at node `1`, traverse to edge between
   # nodes `1` and `2` using a match on a character field
@@ -453,11 +454,11 @@ test_that("selective traversals with `trav_out_edge()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(1) %>%
-    trav_out_edge(edge_attr = "rel", match = "related_to")
+    trav_out_edge("rel == 'related_to'")
 
   # Expect that the edge `1` -> `2` is the
   # current selection
-  expect_equal(get_selection(graph), "1 -> 2")
+  expect_equal(get_selection(graph), 1)
 
   # Starting at node `1`, attempt to traverse to edge
   # between nodes `1` and `2` using a match expression
@@ -466,11 +467,11 @@ test_that("selective traversals with `trav_out_edge()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(1) %>%
-    trav_out_edge(edge_attr = "rel", match = "belongs_with")
+    trav_out_edge("rel == 'belongs_with'")
 
   # Expect that node `1` is the current selection
   # (since no traversal had occurred)
-  expect_equal(get_selection(graph), "1")
+  expect_equal(get_selection(graph), 1)
 })
 
 test_that("selective traversals with `trav_in_edge()` are possible", {
@@ -478,92 +479,92 @@ test_that("selective traversals with `trav_in_edge()` are possible", {
   # Create a graph
   graph <-
     create_graph() %>%
-    add_node %>%
-    add_node %>%
-    add_node %>%
-    add_node %>%
+    add_node() %>%
+    add_node() %>%
+    add_node() %>%
+    add_node() %>%
     add_edge(1, 2) %>%
     add_edge(2, 3) %>%
     add_edge(3, 4) %>%
-    select_nodes %>%
+    select_nodes() %>%
     set_node_attrs_ws("type", "circle") %>%
     clear_selection %>%
     select_nodes_by_id(c(2, 3)) %>%
     set_node_attrs_ws("data_value", 10) %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(4) %>%
     set_node_attrs_ws("shape", "square") %>%
     set_node_attrs_ws("data_value", 5) %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(1) %>%
     set_node_attrs_ws("shape", "triangle") %>%
     set_node_attrs_ws("data_value", 5) %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_edges() %>%
     set_edge_attrs_ws("data_value", 5) %>%
     set_edge_attrs_ws("rel", "related_to") %>%
-    clear_selection
+    clear_selection()
 
   # Starting at node `4`, traverse to edge between
   # nodes `3` and `4` with a match expression (==)
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(4) %>%
-    trav_in_edge(edge_attr = "data_value", match = "==5")
+    trav_in_edge("data_value == 5")
 
   # Expect that the edge `3` -> `4` is the
   # current selection
-  expect_equal(get_selection(graph), "3 -> 4")
+  expect_equal(get_selection(graph), 3)
 
   # Starting at node `4`, traverse to edge between
   # nodes `3` and `4` with a match expression (<)
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(4) %>%
-    trav_in_edge(edge_attr = "data_value", match = "<10")
+    trav_in_edge("data_value < 10")
 
   # Expect that the edge `3` -> `4` is the
   # current selection
-  expect_equal(get_selection(graph), "3 -> 4")
+  expect_equal(get_selection(graph), 3)
 
   # Starting at node `4`, traverse to edge between
   # nodes `3` and `4` with a match expression (>)
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(4) %>%
-    trav_in_edge(edge_attr = "data_value", match = ">2")
+    trav_in_edge("data_value > 2")
 
   # Expect that the edge `3` -> `4` is the
   # current selection
-  expect_equal(get_selection(graph), "3 -> 4")
+  expect_equal(get_selection(graph), 3)
 
   # Starting at node `4`, traverse to edge between
   # nodes `3` and `4` with a match expression (!=)
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(4) %>%
-    trav_in_edge(edge_attr = "data_value", match = "!=1")
+    trav_in_edge("data_value != 1")
 
   # Expect that the edge `3` -> `4` is the
   # current selection
-  expect_equal(get_selection(graph), "3 -> 4")
+  expect_equal(get_selection(graph), 3)
 
   # Starting at node `4`, attempt to traverse to edge
   # between nodes `3` and `4` using a match expression
   # that won't yield a match
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(4) %>%
-    trav_in_edge(edge_attr = "data_value", match = "!=5")
+    trav_in_edge("data_value != 5")
 
   # Expect that node `4` is the current selection
   # (since no traversal had occurred)
-  expect_equal(get_selection(graph), "4")
+  expect_equal(get_selection(graph), 4)
 
   # Starting at node `4`, traverse to edge between
   # nodes `3` and `4` using a match on a
@@ -572,11 +573,11 @@ test_that("selective traversals with `trav_in_edge()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(4) %>%
-    trav_in_edge(edge_attr = "rel", match = "related_to")
+    trav_in_edge("rel == 'related_to'")
 
   # Expect that the edge `3` -> `4` is the
   # current selection
-  expect_equal(get_selection(graph), "3 -> 4")
+  expect_equal(get_selection(graph), 3)
 
   # Starting at node `4`, attempt to traverse to edge
   # between nodes `3` and `4` using a match expression
@@ -585,11 +586,11 @@ test_that("selective traversals with `trav_in_edge()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(4) %>%
-    trav_in_edge(edge_attr = "rel", match = "belongs_with")
+    trav_in_edge("rel == 'belongs_with'")
 
   # Expect that node `4` is the current selection
   # (since no traversal had occurred)
-  expect_equal(get_selection(graph), "4")
+  expect_equal(get_selection(graph), 4)
 })
 
 test_that("selective traversals with `trav_in_node()` are possible", {
@@ -597,113 +598,113 @@ test_that("selective traversals with `trav_in_node()` are possible", {
   # Create a graph
   graph <-
     create_graph() %>%
-    add_node %>%
-    add_node %>%
-    add_node %>%
-    add_node %>%
+    add_node() %>%
+    add_node() %>%
+    add_node() %>%
+    add_node() %>%
     add_edge(1, 2) %>%
     add_edge(2, 3) %>%
     add_edge(3, 4) %>%
-    select_nodes %>%
+    select_nodes() %>%
     set_node_attrs_ws("type", "circle") %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(c(2, 3)) %>%
     set_node_attrs_ws("data_value", 10) %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(4) %>%
     set_node_attrs_ws("shape", "square") %>%
     set_node_attrs_ws("data_value", 5) %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(1) %>%
     set_node_attrs_ws("shape", "triangle") %>%
     set_node_attrs_ws("data_value", 5) %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_edges() %>%
     set_edge_attrs_ws("data_value", 5) %>%
     set_edge_attrs_ws("rel", "related_to") %>%
-    clear_selection
+    clear_selection()
 
   # Starting at edge `3` -> `4`, traverse to node `4`
   # with a match expression (==)
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_edges(from = 3, to = 4) %>%
-    trav_in_node(node_attr = "data_value", match = "==5")
+    trav_in_node("data_value == 5")
 
   # Expect that the node `4` is the current selection
-  expect_equal(get_selection(graph), "4")
+  expect_equal(get_selection(graph), 4)
 
   # Starting at edge `3` -> `4`, traverse to node `4`
   # with a match expression (<)
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_edges(from = 3, to = 4) %>%
-    trav_in_node(node_attr = "data_value", match = "<10")
+    trav_in_node("data_value < 10")
 
   # Expect that the node `4` is the current selection
-  expect_equal(get_selection(graph), "4")
+  expect_equal(get_selection(graph), 4)
 
   # Starting at edge `3` -> `4`, traverse to node `4`
   # with a match expression (>)
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_edges(from = 3, to = 4) %>%
-    trav_in_node(node_attr = "data_value", match = ">1")
+    trav_in_node("data_value > 1")
 
   # Expect that the node `4` is the current selection
-  expect_equal(get_selection(graph), "4")
+  expect_equal(get_selection(graph), 4)
 
   # Starting at edge `3` -> `4`, traverse to node `4`
   # with a match expression (!=)
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_edges(from = 3, to = 4) %>%
-    trav_in_node(node_attr = "data_value", match = "!=1")
+    trav_in_node("data_value != 1")
 
   # Expect that the node `4` is the current selection
-  expect_equal(get_selection(graph), "4")
+  expect_equal(get_selection(graph), 4)
 
   # Starting at edge `3` -> `4`, attempt to traverse to
   # node `4` using a match expression that won't
   # yield a match
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_edges(from = 3, to = 4) %>%
-    trav_in_node(node_attr = "data_value", match = "!=5")
+    trav_in_node("data_value != 5")
 
   # Expect that the edge `3` -> `4` is the current
   # selection (since no traversal had occurred)
-  expect_equal(get_selection(graph), "3 -> 4")
+  expect_equal(get_selection(graph), 3)
 
   # Starting at node `4`, traverse to edge between
   # nodes `3` and `4` using a match on a
   # character field
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_edges(from = 3, to = 4) %>%
-    trav_in_node(node_attr = "shape", match = "square")
+    trav_in_node("shape == 'square'")
 
   # Expect that the node `4` is the current selection
-  expect_equal(get_selection(graph), "4")
+  expect_equal(get_selection(graph), 4)
 
   # Starting at edge `3` -> `4`, attempt to traverse
   # to node `4` using a match on a character field
   # that won't yield a match
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_edges(from = 3, to = 4) %>%
-    trav_in_node(node_attr = "shape", match = "triangle")
+    trav_in_node("shape == 'triangle'")
 
   # Expect that the edge `3` -> `4` is the current
   # selection (since no traversal had occurred)
-  expect_equal(get_selection(graph), "3 -> 4")
+  expect_equal(get_selection(graph), 3)
 })
 
 test_that("selective traversals with `trav_out_node()` are possible", {
@@ -711,112 +712,111 @@ test_that("selective traversals with `trav_out_node()` are possible", {
   # Create a graph
   graph <-
     create_graph() %>%
-    add_node %>%
-    add_node %>%
-    add_node %>%
-    add_node %>%
+    add_node() %>%
+    add_node() %>%
+    add_node() %>%
+    add_node() %>%
     add_edge(1, 2) %>%
     add_edge(2, 3) %>%
     add_edge(3, 4) %>%
-    select_nodes %>%
+    select_nodes() %>%
     set_node_attrs_ws("type", "circle") %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(c(2, 3)) %>%
     set_node_attrs_ws("data_value", 10) %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(4) %>%
     set_node_attrs_ws("shape", "square") %>%
     set_node_attrs_ws("data_value", 5) %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_nodes_by_id(1) %>%
     set_node_attrs_ws("shape", "triangle") %>%
     set_node_attrs_ws("data_value", 5) %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_edges() %>%
     set_edge_attrs_ws("data_value", 5) %>%
     set_edge_attrs_ws("rel", "related_to") %>%
-    clear_selection
+    clear_selection()
 
   # Starting at edge `1` -> `2`, traverse to node `1`
   # with a match expression (==)
   graph <-
     graph %>%
-    clear_selection %>%
     select_edges(from = 1, to = 2) %>%
-    trav_out_node(node_attr = "data_value", match = "==5")
+    trav_out_node("data_value == 5")
 
   # Expect that the node `1` is the current selection
-  expect_equal(get_selection(graph), "1")
+  expect_equal(get_selection(graph), 1)
 
   # Starting at edge `1` -> `2`, traverse to node `1`
   # with a match expression (<)
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_edges(from = 1, to = 2) %>%
-    trav_out_node(node_attr = "data_value", match = "<10")
+    trav_out_node("data_value < 10")
 
   # Expect that the node `1` is the current selection
-  expect_equal(get_selection(graph), "1")
+  expect_equal(get_selection(graph), 1)
 
   # Starting at edge `1` -> `2`, traverse to node `1`
   # with a match expression (>)
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_edges(from = 1, to = 2) %>%
-    trav_out_node(node_attr = "data_value", match = ">1")
+    trav_out_node("data_value > 1")
 
   # Expect that the node `1` is the current selection
-  expect_equal(get_selection(graph), "1")
+  expect_equal(get_selection(graph), 1)
 
   # Starting at edge `1` -> `2`, traverse to node `1`
   # with a match expression (!=)
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_edges(from = 1, to = 2) %>%
-    trav_out_node(node_attr = "data_value", match = "!=1")
+    trav_out_node("data_value != 1")
 
   # Expect that the node `1` is the current selection
-  expect_equal(get_selection(graph), "1")
+  expect_equal(get_selection(graph), 1)
 
   # Starting at edge `1` -> `2`, attempt to traverse to
   # node `1` using a match expression that won't
   # yield a match
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_edges(from = 1, to = 2) %>%
-    trav_out_node(node_attr = "data_value", match = "!=5")
+    trav_out_node("data_value != 5")
 
   # Expect that the edge `1` -> `2` is the current
   # selection (since no traversal had occurred)
-  expect_equal(get_selection(graph), "1 -> 2")
+  expect_equal(get_selection(graph), 1)
 
   # Starting at edge `1` -> `2`, traverse to node `1`
   # using a match on a character field
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_edges(from = 1, to = 2) %>%
-    trav_out_node(node_attr = "shape", match = "triangle")
+    trav_out_node("shape == 'triangle'")
 
   # Expect that the node `1` is the current selection
-  expect_equal(get_selection(graph), "1")
+  expect_equal(get_selection(graph), 1)
 
   # Starting at edge `1` -> `2`, attempt to traverse to
   # node `1` using a match on a character field that
   # won't yield a match
   graph <-
     graph %>%
-    clear_selection %>%
+    clear_selection() %>%
     select_edges(from = 1, to = 2) %>%
-    trav_out_node(node_attr = "shape", match = "circle")
+    trav_out_node("shape == 'circle'")
 
   # Expect that the edge `1` -> `2` is the current
   # selection (since no traversal had occurred)
-  expect_equal(get_selection(graph), "1 -> 2")
+  expect_equal(get_selection(graph), 1)
 })
 
 test_that("selective traversals with `trav_both()` are possible", {
@@ -856,11 +856,10 @@ test_that("selective traversals with `trav_both()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(3) %>%
-    trav_both(node_attr = "data_value", match = "==10")
+    trav_both("data_value == 10")
 
-  # Expect that nodes `2` and `4` are in the
-  # current selection
-  expect_true(all(get_selection(graph) %in% c("2", "4")))
+  # Expect that node `2` is in the current selection
+  expect_equal(get_selection(graph), 2)
 
   # Starting at node `3`, traverse to nodes `2` and `4`
   # with a match expression (<)
@@ -868,11 +867,11 @@ test_that("selective traversals with `trav_both()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(3) %>%
-    trav_both(node_attr = "data_value", match = "<15")
+    trav_both("data_value < 15")
 
   # Expect that nodes `2` and `4` are in the
   # current selection
-  expect_true(all(get_selection(graph) %in% c("2", "4")))
+  expect_equal(get_selection(graph), c(2, 4))
 
   # Starting at node `3`, traverse to nodes `2` and `4`
   # with a match expression (>)
@@ -880,11 +879,10 @@ test_that("selective traversals with `trav_both()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(3) %>%
-    trav_both(node_attr = "data_value", match = ">5")
+    trav_both("data_value > 5")
 
-  # Expect that nodes `2` and `4` are in the
-  # current selection
-  expect_true(all(get_selection(graph) %in% c("2", "4")))
+  # Expect that node `2` is in the current selection
+  expect_equal(get_selection(graph), 2)
 
   # Starting at node `3`, traverse to nodes `2` and `4`
   # with a match expression (!=)
@@ -892,11 +890,10 @@ test_that("selective traversals with `trav_both()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(3) %>%
-    trav_both(node_attr = "data_value", match = "!=5")
+    trav_both("data_value != 5")
 
-  # Expect that nodes `2` and `4` are in the
-  # current selection
-  expect_true(all(get_selection(graph) %in% c("2", "4")))
+  # Expect that node `2` is in the current selection
+  expect_equal(get_selection(graph), 2)
 
   # Starting at node `3`, attempt traverse to nodes
   # `2` and `4` with a match expression that won't
@@ -905,10 +902,10 @@ test_that("selective traversals with `trav_both()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(3) %>%
-    trav_both(node_attr = "data_value", match = "!=10")
+    trav_both("data_value != 10")
 
-  # Expect that the node `3` is the current selection
-  expect_equal(get_selection(graph), "4")
+  # Expect that the node `4` is the current selection
+  expect_equal(get_selection(graph), 4)
 
   # Starting at node `3`, traverse to nodes `2` and `4`
   # with a character match expression
@@ -916,11 +913,11 @@ test_that("selective traversals with `trav_both()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(3) %>%
-    trav_both(node_attr = "type", match = "circle")
+    trav_both("type == 'circle'")
 
   # Expect that nodes `2` and `4` are in the
   # current selection
-  expect_true(all(get_selection(graph) %in% c("2", "4")))
+  expect_equal(get_selection(graph), c(2, 4))
 
   # Starting at node `3`, attempt to traverse to nodes
   # `2` and `4` with a character match expression that
@@ -929,10 +926,10 @@ test_that("selective traversals with `trav_both()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(3) %>%
-    trav_both(node_attr = "shape", match = "square")
+    trav_both("shape == 'square'")
 
   # Expect that the node `4` is the current selection
-  expect_equal(get_selection(graph), "4")
+  expect_equal(get_selection(graph), 4)
 
   # Starting at node `2`, traverse to nodes `1` and `3`
   # with a character match expression
@@ -940,10 +937,10 @@ test_that("selective traversals with `trav_both()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(2) %>%
-    trav_both(node_attr = "shape", match = "triangle")
+    trav_both("shape == 'triangle'")
 
   # Expect that the node `1` is the current selection
-  expect_equal(get_selection(graph), "1")
+  expect_equal(get_selection(graph), 1)
 
   # Starting at node `2`, traverse to node `2` with a
   # character match expression
@@ -951,8 +948,66 @@ test_that("selective traversals with `trav_both()` are possible", {
     graph %>%
     clear_selection %>%
     select_nodes_by_id(2) %>%
-    trav_both(node_attr = "shape", match = "circle")
+    trav_both("shape == 'circle'")
 
-  # Expect that the node `3` is the current selection
-  expect_equal(get_selection(graph), "2")
+  # Expect that the node `2` is the current selection
+  expect_equal(get_selection(graph), 2)
+})
+
+test_that("selective traversals with `trav_both_edge()` are possible", {
+
+  # Create a graph
+  graph <-
+    create_graph() %>%
+    add_node() %>%
+    add_node() %>%
+    add_node() %>%
+    add_node() %>%
+    add_edge(1, 2) %>%
+    add_edge(2, 3) %>%
+    add_edge(3, 4) %>%
+    select_nodes() %>%
+    set_node_attrs_ws("type", "circle") %>%
+    clear_selection() %>%
+    select_nodes_by_id(c(2, 3)) %>%
+    set_node_attrs_ws("data_value", 10) %>%
+    clear_selection() %>%
+    select_nodes_by_id(4) %>%
+    set_node_attrs_ws("shape", "square") %>%
+    set_node_attrs_ws("data_value", 5) %>%
+    clear_selection() %>%
+    select_nodes_by_id(1) %>%
+    set_node_attrs_ws("shape", "triangle") %>%
+    set_node_attrs_ws("data_value", 5) %>%
+    clear_selection() %>%
+    select_edges() %>%
+    set_edge_attrs_ws("data_value", c(1, 2, 3)) %>%
+    set_edge_attrs_ws("rel", "related_to") %>%
+    clear_selection()
+
+  # Starting at node `3`, traverse to edges `3` -> `4`
+  # and `2` -> `3` with a match expression (==)
+  graph <-
+    graph %>%
+    clear_selection %>%
+    select_nodes_by_id(3) %>%
+    trav_both_edge("data_value == 2")
+
+  # Expect that edge `2` is in the current selection
+  expect_equal(get_selection(graph), 2)
+
+  # Expect an error if the graph has no selection of nodes
+  expect_error(
+    graph %>%
+      clear_selection %>%
+      trav_both_edge("data_value == 2"))
+
+  # Return the same graph if a traversal with conditions
+  # does not result in a traversal
+  expect_equal(
+    graph %>%
+      clear_selection %>%
+      select_nodes_by_id(3) %>%
+      trav_both_edge("data_value == 6") %>%
+      get_selection(), 3)
 })
